import { useCallback } from "react";
import { useMaterialStore } from "../../../../../store/simulation/useMaterialStore";
import { useProductStore } from "../../../../../store/simulation/useProductStore";
import { useSelectedProduct } from "../../../../../store/simulation/useSimulationStore";
import { usePlayButtonStore } from "../../../../../store/usePlayButtonStore";
import * as THREE from 'three';

export function useSwapHandler() {
    const { addMaterial, getMaterialByCurrentPointUuid, setMaterial } = useMaterialStore();
    const { getPointUuidByActionUuid } = useProductStore();
    const { selectedProduct } = useSelectedProduct();
    const { isPlaying } = usePlayButtonStore();

    const swapLogStatus = (materialUuid: string, status: string) => {
        // console.log(`${materialUuid}, ${status}`);
    }

    const handleSwap = useCallback((action: ConveyorAction) => {
        if (!action || action.actionType !== 'swap' || !isPlaying) return;

        const { material: newMaterialType, actionUuid } = action;
        const pointUuid = getPointUuidByActionUuid(selectedProduct.productId, actionUuid);

        if (!pointUuid) return;

        const currentMaterial = getMaterialByCurrentPointUuid(pointUuid);

        if (currentMaterial) {
            setMaterial(currentMaterial.materialId, newMaterialType);
            swapLogStatus(currentMaterial.materialId, `Swapped to ${newMaterialType}`);
        }

    }, [addMaterial, getMaterialByCurrentPointUuid, getPointUuidByActionUuid, isPlaying, setMaterial, selectedProduct.productId]);

    return {
        handleSwap,
    };
}