import { useCallback, useEffect, useRef } from 'react';
import { useActionHandler } from '../../actions/useActionHandler';
import { useProductStore } from '../../../../store/simulation/useProductStore';
import { useSelectedProduct } from '../../../../store/simulation/useSimulationStore';
import { useMaterialStore } from '../../../../store/simulation/useMaterialStore';

export function useTriggerHandler() {
    const { getActionByUuid, getEventByTriggerUuid, getEventByModelUuid } = useProductStore();
    const { handleAction } = useActionHandler();
    const { getMaterialByCurrentModelUuid, setCurrentLocation, setNextLocation } = useMaterialStore();
    const { selectedProduct } = useSelectedProduct();

    const handleTrigger = (trigger: TriggerSchema, action: Action) => {

        const fromEvent = getEventByTriggerUuid(selectedProduct.productId, trigger.triggerUuid);

        const toEvent = getEventByModelUuid(selectedProduct.productId, trigger.triggeredAsset?.triggeredModel.modelUuid || '');

        if (fromEvent?.type === 'transfer') {
            if (toEvent?.type === 'transfer') {
                // Transfer to Transfer
                if (trigger.triggeredAsset && trigger.triggeredAsset.triggeredPoint && trigger.triggeredAsset.triggeredAction) {
                    const material = getMaterialByCurrentModelUuid(fromEvent.modelUuid);
                    if (material) {
                        if (material.next) {

                            setCurrentLocation(material.materialId, {
                                modelUuid: material.next.modelUuid,
                                pointUuid: material.next.pointUuid,
                                actionUuid: trigger.triggeredAsset?.triggeredAction?.actionUuid,
                            });

                            setNextLocation(material.materialId, {
                                modelUuid: trigger.triggeredAsset.triggeredModel.modelUuid,
                                pointUuid: trigger.triggeredAsset.triggeredPoint.pointUuid,
                            });
                        }
                        handleAction(action);
                    }
                }
            } else if (toEvent?.type === 'vehicle') {
                // Transfer to Vehicle

            } else if (toEvent?.type === 'machine') {
                // Transfer to Machine

            } else if (toEvent?.type === 'roboticArm') {
                // Transfer to Robotic Arm

            } else if (toEvent?.type === 'storageUnit') {
                // Transfer to Storage Unit

            }
        } else if (fromEvent?.type === 'vehicle') {
            if (toEvent?.type === 'transfer') {
                // Vehicle to Transfer

            } else if (toEvent?.type === 'vehicle') {
                // Vehicle to Vehicle

            } else if (toEvent?.type === 'machine') {
                // Vehicle to Machine

            } else if (toEvent?.type === 'roboticArm') {
                // Vehicle to Robotic Arm

            } else if (toEvent?.type === 'storageUnit') {
                // Vehicle to Storage Unit

            }
        } else if (fromEvent?.type === 'machine') {
            if (toEvent?.type === 'transfer') {
                // Machine to Transfer

            } else if (toEvent?.type === 'vehicle') {
                // Machine to Vehicle

            } else if (toEvent?.type === 'machine') {
                // Machine to Machine

            } else if (toEvent?.type === 'roboticArm') {
                // Machine to Robotic Arm

            } else if (toEvent?.type === 'storageUnit') {
                // Machine to Storage Unit

            }
        } else if (fromEvent?.type === 'roboticArm') {
            if (toEvent?.type === 'transfer') {
                // Robotic Arm to Transfer

            } else if (toEvent?.type === 'vehicle') {
                // Robotic Arm to Vehicle

            } else if (toEvent?.type === 'machine') {
                // Robotic Arm to Machine

            } else if (toEvent?.type === 'roboticArm') {
                // Robotic Arm to Robotic Arm

            } else if (toEvent?.type === 'storageUnit') {
                // Robotic Arm to Storage Unit

            }
        } else if (fromEvent?.type === 'storageUnit') {
            if (toEvent?.type === 'transfer') {
                // Storage Unit to Transfer

            } else if (toEvent?.type === 'vehicle') {
                // Storage Unit to Vehicle

            } else if (toEvent?.type === 'machine') {
                // Storage Unit to Machine

            } else if (toEvent?.type === 'roboticArm') {
                // Storage Unit to Robotic Arm

            } else if (toEvent?.type === 'storageUnit') {
                // Storage Unit to Storage Unit

            }
        }
    }

    const triggerPointActions = useCallback((action: Action) => {
        if (!action) return;

        action.triggers.forEach(trigger => {
            switch (trigger.triggerType) {
                case 'onStart':
                    break;
                case 'onComplete':
                    handleTrigger(trigger, action);
                    break;
                case 'onStop':
                    break;
                case 'onError':
                    break;
                case 'delay':
                    break;
                default:
                    console.warn(`Unknown trigger type: ${trigger.triggerType}`);
            }
        });
    }, []);

    return {
        triggerPointActions
    };
}